/********************************************************
 * batch_b -- Create batch objects for backing up	*
 * 							*
 * 	Handles all general stuff.  Which is actually	*
 * 	very little since most of the work is done	*
 * 	in the batch specific objects.			*
 ********************************************************/
#include <cstring>

#include "magic.h"
#include "config.h"
#include "collect_batch_b.h"
#include "slice_batch_b.h"
#include "util.h"
#include "backup.h"
#include "batch_b.h"

unsigned int batch_b::next_batch_number = 0;
/********************************************************
 * new_Batch -- Create a new batcher object.  Which one *
 * depends on the type name in the configuration	*
 ********************************************************/
batch_b* new_batch(
    const std::string& name, 	// Name of the object
    const config& config	// Configuration information on the object
)
{
    // The type of the object
    std::string type_name = config.get_option(SECTION_BATCH, name, BATCH_TYPE);

    if (str_eq(type_name, BATCH_TYPE_COLLECTION)) {
	return (new collection_batch_b(name, config));
    }
    if (str_eq(type_name, BATCH_TYPE_SLICE)) {
	return (new slice_batch_b(name, config));
    }
    USER_ERROR("Invalid type name " + type_name + " for batch module");
}

/********************************************************
 * batch_info::write_base -- Write out the batch stuff	*
 * to a file.						*
 ********************************************************/
void batch_info_b::write_base(
    std::ostream& out_file
) const {
    out_file << META_BATCH_TYPE << ": " << type << std::endl;
    out_file << META_BATCH_NUMBER << ": " << batch_number << std::endl;
    out_file << META_BATCH_NAME << ": " << name << std::endl;
    out_file << META_BATCH_NAMES_NEEDED << ": " << int(names_needed) << std::endl;
    out_file << META_BATCH_BACKUP_CMD << ": " << backup_cmd << std::endl;
    out_file << META_BATCH_RESTORE_CMD << ": " << restore_cmd << std::endl;
    out_file << META_BATCH_VERIFY_CMD << ": " << verify_cmd << std::endl;

    // Write out an indicator of the number of files that follow
    out_file << META_BATCH_FILES << ": " << files.size() << std::endl;
    // Loop trough each file and write it out
    for (string_set::const_iterator cur_file = files.begin();
	    cur_file != files.end();
	    ++cur_file) {
	out_file << encode_string(*cur_file) << std::endl;
    }
}
