/********************************************************
 * batch_b -- Batch information for a backup.		*
 * 							*
 * This is a small module since most of the work is 	*
 * done in the collection_batch, and slice_batch	*
 * modules.						*
 ********************************************************/
#ifndef __BATCH_B_H__
#define __BATCH_B_H__

#include <fstream>

#include "magic.h"
#include "filer.h"
#include "config.h"
#include "util.h"
#include "batch_info_b.h"

/********************************************************
 * batch_b -- Class to handle backing up of a batch of	*
 * 	files.  					*
 *							*
 * This class is specialized by the different batch	*
 * types (collection, slice.)				*
 ********************************************************/
class batch_b {
    public:
	typedef enum status_enum 
	    {BATCH_NONE, BATCH_FULL, BATCH_PART} status;
    protected:
	static unsigned int next_batch_number;// Batch number of the next batch
	unsigned int batch_number;	 // The batch number of this batch
	std::string name;	// Name of the batch

	std::string backup_cmd;	// Command to do backup
	std::string restore_cmd;// Command to do restore
	std::string verify_cmd; // Command to verify the I/O

	bool done;		// True if we're done
	bool names_needed;	// True if names are needed

    public:
	batch_b(
	    const std::string& i_name,	// Name of the batch
	    const config& config	// Global configuration information
       ) : name(i_name), done(false) {
	    // Command to do the backup
	    backup_cmd = config.get_option(SECTION_BATCH, i_name, 
		    BATCH_CMD_BACKUP_CMD);

	    // Command to do the restore
	    restore_cmd = config.get_option(SECTION_BATCH, i_name, 
		    BATCH_CMD_RESTORE_CMD);

	    // Command to do the verify
	    verify_cmd = config.get_option(SECTION_BATCH, i_name, 
		    BATCH_CMD_VERIFY_CMD);

	    names_needed = true;
	    if (config.defined(SECTION_BATCH, i_name, 
			BATCH_NEED_FILES, 0)) {

		// The value of the option
		std::string needed_value = config.get_option(
			SECTION_BATCH, name, 
			    BATCH_NEED_FILES, 0);

		if (str_eq(needed_value, "Yes")) {
		    names_needed = true;
		} else if (str_eq(needed_value, "No")) {
		    names_needed = false;
		} else {
		    USER_ERROR(std::string("Option ") + 
			    SECTION_BATCH + "->" + name +
			    "->" + BATCH_NEED_FILES + " Illegal value " +
			    needed_value);
		}
	    }
	}
	virtual ~batch_b() {};
    private:
	batch_b(const batch_b&); // No copy constructor
	batch_b &operator = (const batch_b&);	// No assignment operator
    public:
	virtual status add_files(filer &the_filer) = 0;
	virtual batch_info_b* create_batch(void) = 0;
};

/********************************************************
 * new_Batch -- Create a new batch object		*
 ********************************************************/
extern batch_b* new_batch(const std::string& name, const config& config);

#endif /* __BATCH_B_H__ */

