/********************************************************
 * batch_r -- Module to handle the batching part of 	*
 * 	a restore.					*
 ********************************************************/
#ifndef __BATCH_R_H__
#define __BATCH_R_H__

#include <string>
#include <fstream>

#include "io_r.h"
#include "meta_r.h"

/********************************************************
 * batch_r -- Object to handle restoration of a batch	*
 * of files.						*
 ********************************************************/
class batch_r {
    public:
	typedef enum status_enum 
	    {BATCH_NONE, BATCH_FULL, BATCH_PART} status;

	batch_r(void) {}
	virtual ~batch_r() {};
    private:
	batch_r(const batch_r&); // No copy constructor
	batch_r &operator = (const batch_r&);	// No assignment operator
    public:
	// Verify a batch
	virtual void verify(
	    const meta_r::info_set& info,
	    io_r* const io 
	) = 0;

	// Restore a batch
	virtual void restore(
	     const meta_r::info_set& set,
	     io_r* const io,
	     const string_set& files
	) = 0;
};

/********************************************************
 * new_batch_r -- Create a new batch object		*
 ********************************************************/
extern batch_r* new_batch_r(
    const std::string& type	// Information on the batch
);

#endif /* __BATCH_R_H__ */

