/********************************************************
 * Classes for backing things up to CD			*
 ********************************************************/
#ifndef __CD_IO_B_H__
#define __CD_IO_B_H__

#include "magic.h"
#include "meta_b.h"
#include "io_b.h"
#include "cd_io_c.h"

/********************************************************
 * cd_io_info_b -- Information about the CD batch	*
 ********************************************************/
class cd_io_info_b : public io_info_b {
    public:
	const char* file_name;	// File name on the disk

	cd_io_info_b(const unsigned int i_media_sequence,
		     const unsigned int i_file_sequence,
		     const char* i_file_name
	):
	    io_info_b(IO_TYPE_CD, i_media_sequence, i_file_sequence),
	    file_name(strdup(i_file_name))
	{}
	cd_io_info_b(const cd_io_info_b& other): io_info_b(other){
	    file_name = strdup(other.file_name);
	} 
	cd_io_info_b& operator =(const cd_io_info_b& other) {
	    file_name = strdup(other.file_name);
	    return (*this);
	}
	~cd_io_info_b() {
	    free(const_cast<char*>(file_name));
	    file_name = NULL;
	}
    public:
	void write(std::ostream& out_file) const {
	    write_base(out_file);
	    out_file << META_CD_FILE << ": " << file_name << std::endl;
	    out_file << META_EOR << std::endl;
	}
};

/********************************************************
 * cd_io_b -- Object to handle the writing of		*
 * 	batch files to the CD and the updating 		*
 * 	of the metadata associated with them.		*
 ********************************************************/
class cd_io_b: public io_b, public cd_io_c {
    private:
	std::string image_command;	// Command to make an image
	std::string burn_command;	// Command to burn a CD
	std::string pre_image;		// Pre-image command

	size_t cd_size;			// Number of data bytes CD can hold

	meta_b* cd_meta;		// Meta data for this CD
	unsigned int current_size;	// Size of the data on the disk so far

	string_set file_list;		// List of files on the media

	int cd_number;			// Number of the cd written
	unsigned int file_sequence;	// Sequence number for batch files

	std::string image_dir;		// Directory for the current image

	bool first;			// True if this is the first time

    public:
	cd_io_b(const std::string& name,
	    const config& config);
	~cd_io_b() {};

    private:
	cd_io_b(const cd_io_b&);	// No copy constructor
	cd_io_b& operator = (const cd_io_b&);//No assignment operator
    public:
	void write(const batch_info_b* const info);
	void finish(const std::string meta, const std::string report);
    private:
	void burn_cd(const bool last);	// Burn a CD

	// Write the label file
	void write_label(
	    const bool last
	); 

	// Really burn the CD
	void finish_cd(
	    const std::string global_meta,	// File to write global meta data
	    const std::string meta_report	// Report file for meta data
	);
	void new_cd(void);
};

#endif /* __CD_IO_B_H__ */

