#error Include me out
/********************************************************
 * file_table -- A table to hold file names		*
 * 	used to keep copies of the strings we use most.	*
 *********************************************************/
#ifndef __FILE_TABLE_H__
#define __FILE_TABLE_H__

#include <vector>
#include <set>
#include <assert.h>

class file_table {
    public:
	struct file_index {
	    short int index;	// Index of the file
	};
    private:
	// Vector holding the file information
	typedef std::vector<const char*> file_vector;

	// The vector itself
	file_vector file_array;

	enum {NOT_FOUND = -1};

    public:
	file_table() {}
	// Destructor defaults
    private:
	file_table(const file_table&);	// No copy constructor

	// No assignment operator
	file_table operator = (const file_table&);
    public:
	// Add a file to the list of files there
	void add_file(const char* const name) {
	    if (get_index(name).index != NOT_FOUND)
		    return;

	    file_array.push_back(strdup(name));
	}

	// Get an index of a file
	file_index get_index(const char* const name) {
	    struct file_index result; // The result of the check

	    // Loop through each name in the array 
	    for (file_vector::const_iterator cur_name = file_array.begin();
		    cur_name != file_array.end();
		    ++cur_name) {

		if (strcmp(*cur_name, name) == 0) {
		    result.index = cur_name - file_array.begin();
		    return (result);
		}
	    }
	    result.index = NOT_FOUND;
	    return (result);
	}
	
	// Translate an index to a name
	const char* const index_to_name(const file_index index) {
	    assert(index.index >= 0);
	    assert(static_cast<unsigned int>(index.index) < file_array.size());
	    return (file_array[index.index]);
	}

	// A set of files
	typedef std::set<file_table::file_index> file_index_set;
};

// The master file table
extern file_table master_file_table;

inline bool operator < (
	const file_table::file_index& i1,
	const file_table::file_index& i2)
{
    return (i1.index < i2.index);
}
inline bool operator == (
	const file_table::file_index& i1,
	const file_table::file_index& i2)
{
    return (i1.index == i2.index);
}

inline bool operator != (
	const file_table::file_index& i1,
	const file_table::file_index& i2)
{
    return (i1.index != i2.index);
}



#endif /* __FILE_TABLE_H__ */
