/********************************************************
 * input_list -- Functions that handle the obtaining	*
 * of a list of files to backup.			*
 ********************************************************/
#include <errno.h>
#include <unistd.h>
#include <stdio.h>

#include "tmp_file.h"
#include "backup.h"
#include "input_list.h"
#include "log.h"
#include "proc.h"

/********************************************************
 * input_list::input_list -- Create an input list	*
 ********************************************************/
input_list::input_list(
   const std::string& name,	// The name of the list
   const config &global_config	// Global Configuration Information
) {
    our_config = global_config.get_single(SECTION_INPUT_LIST, name);
}
/********************************************************
 * exec_command -- Execute a command and capture	*
 * the output (and the errors)				*
 ********************************************************/
void input_list::exec_command(
   string_set& result,		// Where to put the results
   const std::string& cmd,	// Type of command
   const char delim		// Delimiter
) {

    if (!our_config.defined(cmd)) {
	return;
    }
    // Current command
    string_vector::const_iterator cur_cmd;
    
    // All the options for this command
    string_vector cmd_list = our_config.get_option_all(cmd);

    for (cur_cmd = cmd_list.begin();
	cur_cmd != cmd_list.end();
	++cur_cmd) {
	
	// Name of the output file
	std::string out_file_name = tmp_name("cmd_out");

	std::string sys_command = (*cur_cmd + " >" + out_file_name);

	// Status of the the command to find the file
	int status = do_system(sys_command.c_str(), LOG_INPUT);
	if (status != 0) {
	    char status_msg[100];	// Message for status information

	    snprintf(status_msg, sizeof(status_msg), 
		    "WARNING: return status %d", status);

	    log_msg(LOG_WARNING, "Warning command " + sys_command);
	    log_msg(LOG_WARNING, status_msg);
	}

	// The file to read containing the list of file names
	std::ifstream in_file(out_file_name.c_str());
	if (in_file.bad()) {
	    SYSTEM_ERROR("Could not open input file " + out_file_name);
	}
	while (1) {
	    std::string line;	// Line from the input

	    getline(in_file, line, delim);
	    if (in_file.eof()) {
		break;
	    }
	    if (in_file.bad()) {
		break;
	    }
	    result.insert(line);
	}
	in_file.close();
	if (! keep_option) {
	    unlink(out_file_name.c_str());
	}
    }
}


/********************************************************
 * find_files -- Find all the files specified by the	*
 * 	configuration specification.			*
 ********************************************************/
string_set input_list::find_files(void) 
{
    string_set result;	// Result of use executing our commands

    // Try Command0 list
    exec_command(result, "Command0", '\0');
    // Try Command list
    exec_command(result, "Command", '\n');

    return (result);
}

