/********************************************************
 * log -- handle logging				*
 ********************************************************/
#include <iostream>

#include "log.h"

static bool console_log_flags[128];	// Flags for logging to console
static bool log_flags[128];	// Flags for logging
/********************************************************
 * log_msg -- Output a message to a log			*
 ********************************************************/
void log_msg(
    const char type,		// Type of message
    const std::string& msg	// Message to send
) {
    if (do_log_option) {
	if (log_flags[type]) 
	    log_file << '(' << type << ')' << msg << std::endl;
    }
    if (console_log_flags[type]) 
	std::cout << '(' << type << ')' << msg << std::endl;
        std::cout.flush();
}

/********************************************************
 * gen_init_log -- Init a single type of log flags	*
 ********************************************************/
static void gen_init_log(
    const char arg_flags[],	// The flag character from the cmd line
    bool flag_array[128]	// The flags to set
) {
    if (strcmp(arg_flags, "+") == 0) {
	// sizeof(log_flags) -- is correct.  flag_array is pointer
	// and won't give the correct report.  (We depend on the 
	// size of our flag arrays to be the same)
	memset(flag_array, true, sizeof(log_flags));
    } else {
	for (const char* cur_char = arg_flags;
	     *cur_char != '\0';
	     ++cur_char) {
	    flag_array[*cur_char & 0x7F] = true;
	}
    }
}

/********************************************************
 * init_log -- Init general logging.			*
 ********************************************************/
void init_log(
    const char arg_flags[]	// The flag character from the cmd line
) 
{
    gen_init_log(arg_flags, log_flags);
}

/********************************************************
 * init_console_log -- Init flags for the console 	*
 * 	logging.					*
 ********************************************************/
void init_console_log(
    const char arg_flags[]	// The flag character from the cmd line
) {
    gen_init_log(arg_flags, console_log_flags);
}
