/********************************************************
 * raw_tape -- Handle low level tape I/O		*
 * 							*
 * There are three types of drivers behind this virtual	*
 * class:						*
 * 	tape_tape -- A real tape device			*
 * 	tape_null -- /dev/null (write only)		*
 * 	tape_file -- Simulate with files.		*
 ********************************************************/
#ifndef __RAW_TAPE_H__
#define __RAW_TAPE_H__

#include <string>

const int ONE_K = 1024;	// A single K for buffering
/********************************************************
 * Virtual class to handle low level tape I/O		*
 ********************************************************/
class raw_tape {
    public:
	// Constructor defaults
	// Copy constructor defaults
	// Assignment operator defaults
	virtual ~raw_tape() {}
    public:
	virtual int copy_to_mt(
	    const std::string& file_name,
	    const int block_size
	) = 0;
	virtual int copy_from_mt(
	    const std::string& file_name,
	    const int block_size
	) = 0;

    public:
	virtual int mt_open(const char *const file, const int line) = 0;
	virtual void mt_close(const char *const file, const int line) = 0;
    public: // Tape operations
	virtual int weof() = 0;
	virtual int rewind() = 0;
	virtual int asf(const int position) = 0;
	virtual int eod() = 0;
	virtual int bsfm(const unsigned int count) = 0;
	virtual bool change_tape(
		const unsigned int tape_number
	) {
	    return (false);
	}
};

#endif /* __RAW_TAPE_H__ */
