/********************************************************
 * tape_file -- Handle low level I/O to a simulated 	*
 * tape.						*
 ********************************************************/
#ifndef __TAPE_FILE_H__
#define __TAPE_FILE_H__

#include "log.h"
#include "exception.h"
#include "util.h"
#include "raw_tape.h"

/********************************************************
 * tape_file -- Simulate a tape with files		*
 ********************************************************/
class tape_file : public raw_tape {
    private:
	// Basename of the simulation
	std::string base_file_name;

	// The file number of the current file
	int current_file_number;

	int max_file_number;	// Largest file number allowed

	int current_tape_number;	// Tape number of current tape
					// (starts with one)

    public:
	explicit tape_file(
	    const std::string& device,
	    const int i_mode
	);
	// Copy constructor defaults
	// Assignment operator defaults
	// Destructor defaults
    public:
	int copy_to_mt(
	    const std::string& file_name,
	    const int block_size
	);
	int copy_from_mt(
	    const std::string& file_name,
	    const int block_size
	);
	bool change_tape(
	    const unsigned int tape_number
	);
    public:
	int mt_open(const char* const file, const int line)
	{
	    log_msg(LOG_TAPE, std::string("mt_open(file): ") + file + ":" + 
			int_to_string(line));
	    current_file_number = 0;
	    return (0);
	}
	void mt_close(const char* const file, const int line)
	{
	    log_msg(LOG_TAPE, std::string("mt_close(file): ") + file + ":" + 
			int_to_string(line));
	}
    public:
	int weof(void) 
	{
	    return (0);
	}
	int rewind(void) 
	{
	    current_file_number = 0;
	    return (0);
	}
	int asf(const int position) 
	{
	    if (position > max_file_number)
		INTERNAL_ERROR("Can go off the end");

	    current_file_number = position;
	    return (0);
	}
	int eod()
	{
	    current_file_number = 0;
	    while (access(make_name().c_str(), F_OK) == 0) {
		++current_file_number;
	    }
	    return (0);
	}
	int bsfm(const unsigned int count)
	{
	    current_file_number -= count;
	    if (current_file_number < 0)
		INTERNAL_ERROR("Tape fell off");
	    return (0);
	}
    private:
	std::string make_name(void);
	void copy_file(const std::string& from, const std::string& to, 
		const unsigned int blocking);
};

#endif /* __TAPE_FILE_H__ */
