/********************************************************
 * Module for handling tape backup.			*
 ********************************************************/
#ifndef __TAPE_IO_B_H__
#define __TAPE_IO_B_H__

#include <sys/fcntl.h>

#include "io_b.h"
#include "tape_io_c.h"
#include "meta_b.h"

/********************************************************
 * tape_io_info_b -- Information about the tape	batch	*
 ********************************************************/
class tape_io_info_b : public io_info_b {
    public:
	tape_io_info_b(const unsigned int i_media_sequence,
		       const unsigned int i_file_sequence
	):
	    io_info_b(IO_TYPE_TAPE, i_media_sequence, i_file_sequence)
	{}
	// Copy Constructor defaults
	// Assignment operator defaults
	// Destructor defaults
    public:
	void write(std::ostream& out_file) const {
	    write_base(out_file);
	}
};
class raw_tape;
class batch_info_b;
/********************************************************
 * tape_io_b -- Backup for tape.			*
 ********************************************************/
class tape_io_b: public io_b, public tape_io_c {
    private:
	// Place to save batches in case of tape error
	std::vector<meta_b::gen_info> save_batches;

	static int next_tape_number;	// Tape number of the next tape
	meta_b	tape_meta;		// Meta data for this tape
	std::string change_script;	// Script to change tapes
	unsigned int safe_count;	// Number of files to back off
    public:
	tape_io_b(
	    const std::string& name,	// The name of the batch
	    const config& config	// The global configuration
	) : tape_io_c(name, config, O_RDWR),
	    change_script(""),
	    safe_count(8)
	{
	    if (config.defined(SECTION_IO, name, IO_TAPE_CHANGE_SCRIPT, 0)) {
		change_script = config.get_option(
		    SECTION_IO, name, IO_TAPE_CHANGE_SCRIPT);
	    }
	    if (config.defined(SECTION_IO, name, IO_TAPE_SAFE_COUNT, 0)) {
		safe_count = atoi(config.get_option(
		    SECTION_IO, name, IO_TAPE_SAFE_COUNT).c_str());
	    }
	}
	~tape_io_b() {};

    private:
	tape_io_b(const tape_io_b&);	// No copy constructor
	tape_io_b& operator = (const tape_io_b&);//No assignment operator
    public:
	void write(const batch_info_b* const info);
	void finish(const std::string meta, const std::string report);
    private:
	void finish_tape();
	void write_eot(const bool continued);
	void next_tape(void);
	void start_tape(void);
};

#endif /* __TAPE_IO_B_H__ */

