/********************************************************
 * Module for restoring a tape based backup		*
 ********************************************************/
#ifndef __TAPE_IO_R_H__
#define __TAPE_IO_R_H__

#include <sys/fcntl.h>

#include "magic.h"
#include "io_r.h"
#include "tape_io_c.h"

/********************************************************
 * tape_io_info_r -- Information about the tape batch	*
 ********************************************************/
class tape_io_info_r : public io_info_r {
    public:
	std::string file_name;	// File name on the disk

	tape_io_info_r(const unsigned int i_media_sequence,
		       const unsigned int i_file_sequence
	):
	    io_info_r(IO_TYPE_TAPE, i_media_sequence, i_file_sequence)
	{}
	// Copy Constructor defaults
	// Assignment operator defaults
	// Destructor defaults
    public:
	void read(std::istream& in_file);
};

/********************************************************
 * Class to handle restores from tape.			*
 ********************************************************/
class tape_io_r: public io_r, public tape_io_c {
    private:
	std::string change_script;	// Script to change tapes
    public:
	tape_io_r(const std::string& name,
	    const config& config):
	    tape_io_c(name, config, O_RDONLY),
	    change_script("")
	{
	    if (config.defined(SECTION_IO, name, IO_TAPE_CHANGE_SCRIPT, 0)) {
		change_script = config.get_option(
		    SECTION_IO, name, IO_TAPE_CHANGE_SCRIPT);
	    }
	}
	~tape_io_r() {};

    private:
	tape_io_r(const tape_io_r&);	// No copy constructor
	tape_io_r& operator = (const tape_io_r&);//No assignment operator
    public:
	// Read the meta file
	std::string get_meta(void);

	// Read the given file from the disk and return it's name
	std::string get_file(const io_info_r* info);

	// Remove a file after we've used it
	void rm_file(const std::string& file);

	// Get the current media number
	int get_cur_media(void);
    private:
	void load_tape(
	   const int tape_number
	);
};

#endif /* __TAPE_IO_R_H__ */

