/********************************************************
 * tmp_file -- handle the generation of temporary 	*
 * 	files.						*
 ********************************************************/
#include <cstring>
#include <cstdio>
#include <sys/param.h>
#include <sys/stat.h>
#include <unistd.h>

#include "magic.h"
#include "config.h"
#include "tmp_file.h"

// Where to put the tmp files
static char tmp_dir[MAXPATHLEN] = "/tmp";

// Sequence number used to generate unique
// file names
static int seq = 0;

/********************************************************
 * tmp_name_init -- Init the temp name system		*
 ********************************************************/
void tmp_name_init(
   const config &config	// Configuration file to use
) {
    // Get the name of the tmp dir (throws exception if not there)
    std::string temp_dir_str = 
	config.get_option(SECTION_OPTIONS, OPTION_GLOBAL, 
		OPTION_TMP_DIR);

    std::strncpy(tmp_dir, temp_dir_str.c_str(), sizeof(tmp_dir));

    struct stat dir_stat;	// Stat of the directory

    if (stat(tmp_dir, &dir_stat) != 0) 
	SYSTEM_ERROR("Could not stat TempDir=" + temp_dir_str);

    if (!S_ISDIR(dir_stat.st_mode))
	USER_ERROR("TempDir=" + temp_dir_str + " not a directory");

    if (access(tmp_dir, W_OK|R_OK|X_OK)) 
	USER_ERROR("TempDir=" + temp_dir_str + " is not accessable");
}

/********************************************************
 * tmp_name -- Produce a temporary name			*
 ********************************************************/
std::string tmp_name(
   const std::string name	// The string to use for a base name
) {
    // The complete file name
    char full_name[MAXPATHLEN];

    pid_t pid = getpid();	// Process id for the temp name

    ++seq;
    sprintf(full_name, "%s/%s.%d.%d",
	    tmp_dir, name.c_str(), pid, seq);
    return (std::string(full_name));
}
